@@ -14,21 +14,29 @@ require './git-autofixup';
 sub check_test_deps {
     if ($OSNAME eq 'MSWin32') {
         plan skip_all => "Windows isn't supported, except with msys or Cygwin";
-    } elsif (!has_git()) {
+    } elsif (!git_version_gte('1.7.4')) {
         plan skip_all => 'git version 1.7.4+ required';
     } elsif ($OSNAME eq 'cygwin' && is_git_for_windows()) {
         plan skip_all => "Can't use Git for Windows with a perl for Cygwin";
     }
 }
 
-# Return true if git version 1.7.4+ is available.
-sub has_git {
+# Return true if at least the given version of git, in X.Y.Z format, is
+# available.
+sub git_version_gte {
+    my $want = shift;
+    my @wants = split /\./, $want;
+    if (@wants != 3) {
+        die "unexpected version format: $want\n";
+    }
+    my ($want_x, $want_y, $want_z) = @wants;
+
     my $stdout = qx{git --version};
     return if $? != 0;
     my ($x, $y, $z) = $stdout =~ /(\d+)\.(\d+)(?:\.(\d+))?/;
     defined $x or die "unexpected output from git: $stdout";
     $z = defined $z ? $z : 0;
-    my $cmp = $x <=> 1 || $y <=> 7 || $z <=> 4;
+    my $cmp = $x <=> $want_x || $y <=> $want_y || $z <=> $want_z;
     return $cmp >= 0;
 }
 
@@ -107,9 +115,12 @@ sub upstreams_ok {
 # Parameters:
 # - a Repo object
 # - a SHA for the last topic branch commit before any fixups were made
-# - a hashref of `git log` outputs, for `fixups`, `staged`, and `unstaged`. If
-#   `staged` isn't given, then it's assumed that there shouldn't be any staged
-#   changes.
+# - a hashref of expected outputs, with the following keys. If fixup_log or
+#   unstaged are undef, then that check is skipped, but if staged=undef we
+#   check that there are no staged changes.
+#       - fixup_log: `git log` output of the fixup commits
+#       - staged: `git diff --cached` output
+#       - unstaged: `git diff` output
 sub repo_state_ok {
     my ($repo, $pre_fixup_rev, $wants) = @_;
     my $ok = 1;
